==> webkit2gtk_2.47.2.orig.tar.xz: webkitgtk-2.47.2/Source/WebCore/platform/graphics/texmap/TextureMapperGCGLPlatformLayer.h <==
/*
 * Copyright (C) 2011, 2012, 2017 Igalia S.L.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301 USA
 */

#pragma once

#if ENABLE(WEBGL) && USE(TEXTURE_MAPPER) && !USE(NICOSIA)

#include "GraphicsContextGLTextureMapperANGLE.h"
#include "PlatformLayer.h"
#include "TextureMapperPlatformLayer.h"
#include "TextureMapperPlatformLayerProxyProvider.h"
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class TextureMapperPlatformLayerProxy;

class TextureMapperGCGLPlatformLayer : public PlatformLayer {
    WTF_MAKE_TZONE_ALLOCATED(TextureMapperGCGLPlatformLayer);
public:
    TextureMapperGCGLPlatformLayer(GraphicsContextGLTextureMapperANGLE&);
    virtual ~TextureMapperGCGLPlatformLayer();

    virtual void paintToTextureMapper(TextureMapper&, const FloatRect& target, const TransformationMatrix&, float opacity);

private:
    GraphicsContextGLTextureMapperANGLE& m_context;
};

} // namespace WebCore

#endif // ENABLE(WEBGL) && USE(TEXTURE_MAPPER)

==> webkit2gtk_2.47.3.orig.tar.xz: webkitgtk-2.47.3/Source/WebCore/platform/graphics/texmap/TextureMapperGCGLPlatformLayer.h <==
/*
 * Copyright (C) 2011, 2012, 2017 Igalia S.L.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301 USA
 */

#pragma once

#if ENABLE(WEBGL) && USE(TEXTURE_MAPPER) && !USE(COORDINATED_GRAPHICS)

#include "GraphicsContextGLTextureMapperANGLE.h"
#include "PlatformLayer.h"
#include "TextureMapperPlatformLayer.h"
#include "TextureMapperPlatformLayerProxyProvider.h"
#include <wtf/TZoneMalloc.h>

namespace WebCore {

class TextureMapperPlatformLayerProxy;

class TextureMapperGCGLPlatformLayer : public PlatformLayer {
    WTF_MAKE_TZONE_ALLOCATED(TextureMapperGCGLPlatformLayer);
public:
    TextureMapperGCGLPlatformLayer(GraphicsContextGLTextureMapperANGLE&);
    virtual ~TextureMapperGCGLPlatformLayer();

    virtual void paintToTextureMapper(TextureMapper&, const FloatRect& target, const TransformationMatrix&, float opacity);

private:
    GraphicsContextGLTextureMapperANGLE& m_context;
};

} // namespace WebCore

#endif // ENABLE(WEBGL) && USE(TEXTURE_MAPPER) && !USE(COORDINATED_GRAPHICS)
